/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkTensorGlyph2.h

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkTensorGlyph2 - scale and orient glyph(s) according to tensor eigenvalues and eigenvectors
// .SECTION Description
// vtkTensorGlyph2 is a filter that copies a geometric representation
// (specified as polygonal data) to every input point. The geometric
// representation, or glyph, can be scaled and/or rotated according to
// the tensor at the input point. Scaling and rotation is controlled
// by the eigenvalues/eigenvectors of the tensor as follows. For each
// tensor, the eigenvalues (and associated eigenvectors) are sorted to
// determine the major, medium, and minor eigenvalues/eigenvectors.
//
// vtkTensorGlyph2 differs from vtkTensorGlyph in that it names the data array
// it creates such that ParaView will be able to use them for coloring and
// further processing.

// .SECTION See Also
// vtkTensorGlyph vtkGlyph3D vtkPointLoad vtkHyperStreamline

#ifndef __vtkTensorGlyph2_h
#define __vtkTensorGlyph2_h

#include "vtkTensorGlyph.h"

// Windows specific stuff------------------------------------------
#if defined(_WIN32) || defined(WIN32) || defined(__CYGWIN__)
#  if defined(VTK_BUILD_SHARED_LIBS)
#    define VTK_TENSORGLYPH_EXPORT  __declspec( dllexport )
#  else
#    define VTK_TENSORGLYPH_EXPORT
#  endif
#else
#  define VTK_TENSORGLYPH_EXPORT
#endif

class VTK_TENSORGLYPH_EXPORT vtkTensorGlyph2 : public vtkTensorGlyph
{
public:
  vtkTypeMacro(vtkTensorGlyph2,vtkTensorGlyph);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description
  // Construct object with scaling on and scale factor 1.0. Eigenvalues are
  // extracted, glyphs are colored with input scalar data, and logarithmic
  // scaling is turned off.
  static vtkTensorGlyph2 *New();

protected:
  vtkTensorGlyph2();
  ~vtkTensorGlyph2();

  // Data generation method
  virtual int RequestData(vtkInformation *, vtkInformationVector **, vtkInformationVector *);
  int RequestUpdateExtent(vtkInformation *, vtkInformationVector **, vtkInformationVector *);

private:
  vtkTensorGlyph2(const vtkTensorGlyph2&);  // Not implemented.
  void operator=(const vtkTensorGlyph2&);  // Not implemented.
};

#endif
